<?php

declare(strict_types=1);

namespace Drupal\node_swapper\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a Node swapper form.
 */
final class NodeSwapperForm extends FormBase {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'node_swapper_node_swapper';
  }

  /**
   * Constructs a new NodeSwapperForm.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {

    $form['src'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('Old Node'),
      '#description' => $this->t('Enter the name or ID of a node you want to decomission. <b>Note:</b> this node will <i>not</i> be destroyed.'),
      '#target_type' => 'node',
      '#required' => TRUE,
    ];

    $form['dest'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('New Node'),
      '#description' => $this->t('Enter the name or ID of the node you want to replace the old node with.'),
      '#target_type' => 'node',
      '#required' => TRUE,
    ];

    $config = $this->configFactory->get('node_swapper.settings');

    $form['unpublish'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Unpublish Old Node'),
      '#description' => $this->t('If checked, the old node will be unpublished'),
      '#default_value' => $config->get('old_node_unpublish'),
    ];

    $form['suffix'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Old Node Suffix'),
      '#description' => $this->t("The suffix to append at the end of the old node's new URL. Alphanumeric entry only."),
      '#default_value' => $config->get('old_node_suffix'),
      '#pattern' => '[a-z0-9-_]+',
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Submit & Review'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $args = [
      'src' => $form_state->getValue('src'),
      'dest' => $form_state->getValue('dest'),
      'suffix' => $form_state->getValue('suffix'),
      'unpublish' => $form_state->getValue('unpublish'),
    ];
    $form_state->setRedirect('node_swapper.node_swapper_confirm', $args);
  }

}
