<?php

declare(strict_types=1);

namespace Drupal\node_swapper\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Node Swapper settings for this site.
 */
final class NodeSwapperSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'node_swapper_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['node_swapper.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['old_node_suffix'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Old Node Suffix'),
      '#description' => $this->t('The default alphanumeric ending to append on old URLs. Ex: /my-url-[SUFFIX]. Users can override this setting on a case-by-case basis.'),
      '#required' => TRUE,
      '#default_value' => $this->config('node_swapper.settings')->get('old_node_suffix'),
      '#pattern' => '[a-z0-9-_]+',
    ];
    $form['old_node_unpublish'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Unpublish Old Nodes'),
      '#description' => $this->t('Whether to unpublish old nodes by default. Users can override this setting on a case-by-case basis.'),
      '#default_value' => $this->config('node_swapper.settings')->get('old_node_unpublish'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('node_swapper.settings')
      ->set('old_node_suffix', $form_state->getValue('old_node_suffix'))
      ->set('old_node_unpublish', $form_state->getValue('old_node_unpublish'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
